@@ -5,11 +5,13 @@ use warnings;
 
 # ABSTRACT: A piece of information to be processed
 
-our $VERSION = '1.111050'; # VERSION
+our $VERSION = '1.111130'; # VERSION
 
 use Moose;
 use DataFlow::Meta;
 
+use namespace::autoclean;
+
 has 'metadata' => (
     'is'  => 'ro',
     'isa' => 'DataFlow::Meta',
@@ -21,7 +23,6 @@ has 'data' => (
 );
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 
 1;
 
@@ -37,7 +38,7 @@ DataFlow::Item - A piece of information to be processed
 
 =head1 VERSION
 
-version 1.111050
+version 1.111130
 
 =head1 SYNOPSIS
 
