@@ -5,9 +5,11 @@ use warnings;
 
 # ABSTRACT: A piece of information metadata
 
-our $VERSION = '1.111050'; # VERSION
+our $VERSION = '1.111130'; # VERSION
 
 use Moose;
+
+use namespace::autoclean;
 use DateTime 0.51;
 
 has 'timestamp'    => ( is => 'rw', isa => 'DateTime', );
@@ -18,7 +20,6 @@ has 'original'     => ( is => 'rw', isa => 'Str', );
 has 'restrictions' => ( is => 'rw', isa => 'Str', );
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 
 1;
 
@@ -34,7 +35,7 @@ DataFlow::Meta - A piece of information metadata
 
 =head1 VERSION
 
-version 1.111050
+version 1.111130
 
 =head1 AUTHOR
 
