@@ -16,18 +16,13 @@ use aliased 'DataFlow::Proc::SimpleFileOutput';
 
 use Data::Dumper;
 
-my $base = join( '/',
-    q{http://www.portaltransparencia.gov.br},
-    q{ceis}, q{EmpresasSancionadas.asp?paramEmpresa=0} );
-
 my $flow = DataFlow->new(
     procs => [
-
-        #        NOP->new( dump_output => 1 ),
         MultiPageURLGenerator->new(
             name => 'multipage',
 
-            #first_page => -2,
+            first_page => -2,
+
             #last_page     => 35,
             produce_last_page => sub {
                 my $url = shift;
@@ -55,36 +50,26 @@ my $flow = DataFlow->new(
                 return $u->as_string;
             },
         ),
-
-        #        NOP->new( dump_output => 1 ),
         NOP->new( deref => 1, name => 'nop', ),
-
-        #        NOP->new( dump_output => 1 ),
         URLRetriever->new( process_into => 1, ),
-
-        #        NOP->new( dump_output => 1 ),
         HTMLFilter->new(
             process_into => 1,
             search_xpath =>
               '//div[@id="listagemEmpresasSancionadas"]/table/tbody/tr',
         ),
-
-        #        NOP->new( dump_output => 1 ),
         HTMLFilter->new(
+            dump_output  => 1,
             search_xpath => '//td',
             result_type  => 'VALUE',
             ref_result   => 1,
         ),
-
-        #        NOP->new( dump_output => 1 ),
         sub {    # remove leading and trailing spaces
             local $_ = shift;
             s/^\s*//;
             s/\s*$//;
             return $_;
         },
-
-        #        NOP->new( dump_output => 1 ),
+        NOP->new( dump_output => 1, ),
         CSV->new(
             direction     => 'TO_CSV',
             text_csv_opts => { binary => 1 },
@@ -96,19 +81,19 @@ my $flow = DataFlow->new(
                 'Data'
             ],
         ),
-
-        #        NOP->new( dump_output => 1 ),
         SimpleFileOutput->new( file => '> /tmp/ceis.csv', ors => "\n" ),
-
-        #        NOP->new( dump_output => 1 ),
     ],
 );
 
-$flow->input($base);
+##############################################################################
 
-#print Dumper($flow);
+my $base = join( '/',
+    q{http://www.portaltransparencia.gov.br},
+    q{ceis}, q{EmpresasSancionadas.asp?paramEmpresa=0} );
+
+$flow->input($base);
 
 my @res = $flow->flush;
 
 #print Dumper(\@res);
-#print Dumper($flow);
+
